/**
 * Copyright (C) 2015 - 2018 Kosmos contact@kosmos.fr
 *
 * Projet: blog
 * Version: 1.08.00-BETA-00
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package fr.kosmos.selenium.blog;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

import fr.kosmos.selenium.annotation.Exigence;
import fr.kosmos.selenium.bean.BlogBean;
import fr.kosmos.selenium.bean.LibelleBean;
import fr.kosmos.selenium.core.KSupTestCase;
import fr.kosmos.selenium.screen.fiche.EcranCreateContentBlog;
import fr.kosmos.selenium.screen.fiche.EcranSearchBlog;
import fr.kosmos.selenium.service.ServiceListeDynamique;
import fr.kosmos.selenium.service.fiche.ServiceBlog;
import fr.kosmos.selenium.utils.RoleTest;

public class ITBlogListeDynamiqueTestCase extends KSupTestCase {

    private ServiceBlog serviceBlog;
    private ServiceListeDynamique<BlogBean, EcranCreateContentBlog, EcranSearchBlog> serviceListeDynamique;

    /**
     * {@inheritDoc}
     */
    @Override
    public void initScreen() {
        serviceBlog = new ServiceBlog(this);
        serviceListeDynamique = new ServiceListeDynamique<>(this, serviceBlog);
    }

    private static List<String> listeToCheck1() {
        final List<String> list = new ArrayList<String>();
        list.add("Matthieu Deforge");
        return list;
    }

    private static List<String> listeToCheck2() {
        final List<String> list = new ArrayList<String>();
        list.add("Blog du Master Geographie");
        return list;
    }

    private static BlogBean listeDynamiqueBean1() {
        final BlogBean bean = new BlogBean();
        bean.setThematique(new LibelleBean("01", "Administratif", StringUtils.EMPTY));
        return bean;
    }

    private static BlogBean listeDynamiqueBean2() {
        final BlogBean bean = new BlogBean();
        bean.setThematique(new LibelleBean("04", "Formation", StringUtils.EMPTY));
        return bean;
    }

    @DataProvider(name = "BeanListeDynamique")
    public static Object[][] listeDynamique() {
        return new Object[][] {
            { listeDynamiqueBean1(), "Titre page libre pour blog 1", listeToCheck1() },
            { listeDynamiqueBean2(), "Titre page libre pour blog 2", listeToCheck2() }
        };
    }

    @Test(dataProvider = "BeanListeDynamique")
    @Exigence(afinDe = "", enTantQue = RoleTest.ADMIN, jeVeux = "", ticketExigence = "KRTO-XXX", ticketTest = "KRTO-XXXX")
    public void testCreationListeDynamiqueBlog(final BlogBean bean, final String titrePageLibre, final List<String> listToCheck) {
        serviceListeDynamique.createListeDynamique(bean, titrePageLibre, listToCheck);
    }
}